@@ -52,6 +52,7 @@ void add_redir_to_proc(char mode, char *proc, redirect_t **predir, int *n_redire
 	assert(mode == 'G' || mode == 'g');
 
 	*predir = (redirect_t *)myrealloc(*predir, (*n_redirect + 1) * sizeof(redirect_t));
+	memset(&(*predir)[*n_redirect], 0x00, sizeof(redirect_t));
 
 	if ((*predir)[*n_redirect].type != REDIRECTTO_NONE) error_exit(FALSE, FALSE, "One can only set one redirection-type per (sub-)window.\n");
 
@@ -86,6 +87,7 @@ void add_redir_to_socket(char filtered, char *prio, char *fac, char *address, re
     int s, sfd = -1;
 
 	*predir = (redirect_t *)myrealloc(*predir, (*n_redirect + 1) * sizeof(redirect_t));
+	memset(&(*predir)[*n_redirect], 0x00, sizeof(redirect_t));
 
 	assert(filtered == 1 || filtered == 0);
 
@@ -181,7 +183,7 @@ void argv_set_window_widths(char *widths)
 		split++;
 		vertical_split = (int *)myrealloc(vertical_split, split * sizeof(int));
 
-		cur_width = get_value_arg("-sw", pnt, VAL_POSITIVE);
+		cur_width = get_value_arg("-sw", pnt, VAL_ZERO_POSITIVE);
 		widths = NULL;
 
 		if (cur_width < 4)
@@ -217,7 +219,7 @@ void argv_set_n_windows_per_column(char *pars)
 		index++;
 		n_win_per_col = (int *)myrealloc(n_win_per_col, index * sizeof(int));
 
-		cur_n = get_value_arg("-sn", pnt, VAL_POSITIVE);
+		cur_n = get_value_arg("-sn", pnt, VAL_ZERO_POSITIVE);
 		pars = NULL;
 
 		if (cur_n < 0)
@@ -288,9 +290,8 @@ int argv_add_re(char *mode, char *pars[], char invert_regex, re **pre_cur, int *
 
 	/* wether to invert the reg exp or not */
 	if ((regex_mode == 'v' || regex_mode == 'm') && invert_regex)
-	{
 		error_exit(FALSE, FALSE, "-e[m] / -ev cannot be used together with -v\n");
-	}
+
 	(*pre)[*n_re].invert_regex = invert_regex;
 
 	/* what to execute (if...) */
@@ -304,13 +305,14 @@ int argv_add_re(char *mode, char *pars[], char invert_regex, re **pre_cur, int *
 	return n_pars_used;
 }
 
-int argv_color_settings(char *mode, char *pars[], char *allcolor, char *curcolor, int *field_index, char **field_delimiter, myattr_t *cdef, term_t *cur_term_emul, int_array_t *cur_color_schemes, myattr_t *alt_col_cdev1, myattr_t *alt_col_cdev2)
+int argv_color_settings(char *mode, char *pars[], char *allcolor, char *curcolor, int *field_index, char **field_delimiter, myattr_t *cdef, term_t *cur_term_emul, int_array_t *cur_color_schemes, myattr_t *alt_col_cdev1, myattr_t *alt_col_cdev2, char *doall)
 {
 	int n_pars_used = 0;
-	char cur_mode = mode[2], doall = 0;
+	char cur_mode = mode[2];
 
+	*doall = 0;
 	if (mode[1] == 'C')
-		doall = 1;
+		*doall = 1;
 
 	if (cur_mode == 's')	/* syslog-file coloring? */
 	{
@@ -368,7 +370,7 @@ int argv_color_settings(char *mode, char *pars[], char *allcolor, char *curcolor
 		error_exit(FALSE, FALSE, "Invalid -c mode: '%c'.\n", cur_mode);
 	}
 
-	if (doall)
+	if (*doall)
 	{
 		*allcolor = cur_mode;
 		*curcolor = 'n';
@@ -433,7 +435,7 @@ int argv_add_stripper(char *mode, char *pars[], strip_t **pstrip, int *n_strip)
 	return n_pars_used;
 }
 
-void add_glob_check(const char *check_glob, int check_interval, char merge, char new_only, const char *cs)
+void add_glob_check(const char *check_glob, int check_interval, char merge, char new_only, const char *cs, const char *label)
 {
 	cdg = (check_dir_glob *)myrealloc(cdg, sizeof(check_dir_glob) * (n_cdg + 1));
 
@@ -444,6 +446,8 @@ void add_glob_check(const char *check_glob, int check_interval, char merge, char
 	cdg[n_cdg].window_nr      = -1;
 	cdg[n_cdg].last_check     = (dtime_t)0.0;
 	cdg[n_cdg].color_scheme   = cs;
+	cdg[n_cdg].label          = label ? mystrdup(label) : NULL;
+
 	n_cdg++;
 }
 
@@ -494,9 +498,10 @@ void do_commandline(int argc, char *argv[])
 	char no_marker_of_other_window = 0;
 	char bufferwhat = -1;
 	int cur_beep_interval = -1;
-
+	char doallterm = 0;
 	char do_add_timestamp = 0;
 	int_array_t conversions = { NULL, 0, 0 };
+	char all_label = 0;
 
 	/* first, before we load the main configfile, see if we should load the global
 	 * file or not
@@ -610,7 +615,7 @@ void do_commandline(int argc, char *argv[])
 			char *prio, *fac, *addr;
 			char filtered;
 
-			// -U[af][as] <facil> <prio> host[:port]
+			/* -U[af][as] <facil> <prio> host[:port] */
 			if (argv[loop][2] != 'a' && argv[loop][2] != 'f')
 				error_exit(FALSE, FALSE, "-Ux where x needs to be either 'a' or 'f'");
 
@@ -777,7 +782,7 @@ void do_commandline(int argc, char *argv[])
 		}
 		else if (argv[loop][0] == '-' && toupper(argv[loop][1]) == 'C')
 		{
-			loop += argv_color_settings(argv[loop], &argv[loop + 1], &allcolor, &curcolor, &field_index, &field_delimiter, &cdef, &cur_term_emul, &cur_color_schemes, &alt_col_cdev1, &alt_col_cdev2);
+			loop += argv_color_settings(argv[loop], &argv[loop + 1], &allcolor, &curcolor, &field_index, &field_delimiter, &cdef, &cur_term_emul, &cur_color_schemes, &alt_col_cdev1, &alt_col_cdev2, &doallterm);
 		}
 		else if (strcmp(argv[loop], "-f") == 0)
 		{
@@ -811,6 +816,12 @@ void do_commandline(int argc, char *argv[])
 		else if (strcasecmp(argv[loop], "--label") == 0)
 		{
 			label = mystrdup(argv[++loop]);
+			all_label = 0;
+		}
+		else if (strcasecmp(argv[loop], "--all-label") == 0)
+		{
+			label = mystrdup(argv[++loop]);
+			all_label = 1;
 		}
 		else if (strcasecmp(argv[loop], "-i") == 0 || argv[loop][0] != '-' ||
 				strcasecmp(argv[loop], "-l") == 0 ||
@@ -1069,7 +1080,8 @@ void do_commandline(int argc, char *argv[])
 				loop++;
 
 			cur -> cdef.term_emul = cur_term_emul;
-			cur_term_emul = TERM_IGNORE;
+			if (doallterm == 0)
+				cur_term_emul = TERM_IGNORE;
 
 			/* redirect input also to a file or pipe */
 			cur -> n_redirect = n_redirect;
@@ -1080,8 +1092,10 @@ void do_commandline(int argc, char *argv[])
 			cur -> beep.beep_interval = cur_beep_interval;
 			cur_beep_interval = -1;
 
-			cur -> label = label;
-			label = NULL;
+			cur -> label = label ? strdup(label) : NULL;
+
+			if (!all_label)
+				label = NULL;
 		}
 		else if (strcmp(argv[loop], "-du") == 0)
 		{
@@ -1132,7 +1146,7 @@ void do_commandline(int argc, char *argv[])
 			if (default_color_scheme && find_colorscheme(default_color_scheme) == -1)
 				error_exit(FALSE, FALSE, "Color scheme '%s' is not known.\n", default_color_scheme);
 
-			add_glob_check(check_glob, check_interval, merge, new_only, default_color_scheme);
+			add_glob_check(check_glob, check_interval, merge, new_only, default_color_scheme, label);
 		}
 		else if (strcmp(argv[loop], "--mark-change") == 0)
 		{
